@@ -1,3 +1,12 @@
+"""
+Modes
+
+  - File
+  - Pipe
+  - ManifestFile
+  - AugmentedManifestFile
+"""
+
 import argparse
 from distutils.util import strtobool
 import os
@@ -36,7 +45,12 @@ def get_mode(mode):
         'ManifestFile',
         'AugmentedManifestFile',
         'ManifestFolder',
-        'AugmentedManifestFolder'
+        'AugmentedManifestFolder',
+        'PipeWrapped',
+        'ManifestFileWrapped',
+        'AugmentedManifestFileWrapped',
+        'ManifestFolderWrapped',
+        'AugmentedManifestFolderWrapped'
     ]:
         return 'Pipe'
     elif mode in ['File', 'EndOfJob', 'Continuous']:
@@ -48,21 +62,65 @@ def get_mode(mode):
 def get_s3_data_type(mode):
     if not mode:
         return 'S3Prefix'
-    elif mode == 'ManifestFile':
+    elif mode.startswith('ManifestFile'):
         return 'ManifestFile'
-    elif mode == 'AugmentedManifestFile':
+    elif mode.startswith('AugmentedManifestFile'):
         return 'AugmentedManifestFile'
-    elif mode == 'ManifestFolder':
+    elif mode.startswith('ManifestFolder'):
         return 'ManifestFile'
-    elif mode == 'AugmentedManifestFolder':
+    elif mode.startswith('AugmentedManifestFolder'):
         return 'AugmentedManifestFile'
-    elif mode in ['File', 'EndOfJob', 'Continuous', 'Pipe']:
+    elif mode in ['File', 'EndOfJob', 'Continuous', 'Pipe', 'PipeWrapped']:
         return 'S3Prefix'
     else:
         raise ValueError("Unknown mode: {}".format(mode))
 
 
+def get_record_wrapping(mode):
+    if not mode:
+        return None
+    elif mode.endswith('Wrapped'):
+        return 'RecordIO'
+    else:
+        return None
+
+
+MODES = [
+    'File',
+    'EndOfJob',
+    'Continuous'
+]
+for m in [
+    'Pipe',
+    'ManifestFile',
+    'AugmentedManifestFile',
+    'ManifestFolder',
+    'AugmentedManifestFolder'
+]:
+    MODES.append(m)
+    MODES.append(f"{m}Wrapped")
+
+
 class PathArgument(object):
+    def copy(
+        self,
+        **kwargs
+    ):
+        vals = {
+            "local": self.local,
+            "remote": self.remote,
+            "optional": self.optional,
+            "mode": self.mode,
+            "attributes": self.attributes,
+            "repeat": self.repeat,
+            "shuffle": self.shuffle,
+            "repeated": self.repeated,
+        }
+        vals.update(kwargs)
+        return PathArgument(
+            **vals
+        )
+
     def __init__(
         self,
         local=None,
@@ -71,21 +129,19 @@ class PathArgument(object):
         mode=None,
         attributes=None,
         repeat=1,
-        shuffle=False
+        shuffle=False,
+        repeated=False
     ):
         self.local = local
         self.remote = remote or 'default'
         self.optional = optional
         self.mode = mode
         self.attributes = attributes
-        self.repeat=repeat
-        self.shuffle=shuffle
+        self.repeat = repeat
+        self.repeated = repeated
+        self.shuffle = shuffle
         if self.mode:
-            assert self.mode in [
-                'Pipe', 'ManifestFile', 'AugmentedManifestFile',
-                'ManifestFolder', 'AugmentedManifestFolder',
-                'File', 'EndOfJob', 'Continuous'
-            ]
+            assert self.mode in MODES
         # if self.optional and self.local:
         #    print("Optional inputs must default to nothing")
 
